<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Không phải tất cả các lịch là hoàn toàn được lưu trong bộ nhớ cache",
"Everything seems to be completely cached" => "Mọi thứ dường như là hoàn toàn được lưu trong bộ nhớ cache",
"No calendars found." => "Không tìm thấy lịch.",
"No events found." => "Không tìm thấy sự kiện nào",
"Wrong calendar" => "Sai lịch",
"You do not have the permissions to edit this event." => "Bạn không có quyền chỉnh sửa sự kiện này.",
"The file contained either no events or all events are already saved in your calendar." => "Các tập tin có hay không có sự kiện hoặc tất cả các sự kiện đã được lưu trong lịch của bạn.",
"Import failed" => "Nhập vào thất bại",
"New Timezone:" => "Múi giờ mới :",
"Timezone changed" => "Thay đổi múi giờ",
"Invalid request" => "Yêu cầu không hợp lệ",
"Calendar" => "Lịch",
"Deletion failed" => "Xóa thất bại",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"group" => "nhóm",
"can edit" => "có thể chỉnh sửa",
"can share" => "có thể chia sẽ",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Chủ nhật",
"Monday" => "Thứ 2",
"Tuesday" => "Thứ 3",
"Wednesday" => "Thứ 4",
"Thursday" => "Thứ 5",
"Friday" => "Thứ ",
"Saturday" => "Thứ 7",
"Sun." => "Chủ nhật",
"Mon." => "Thứ hai",
"Tue." => "Thứ ba",
"Wed." => "Thứ tư",
"Thu." => "Thứ năm",
"Fri." => "Thứ sáu",
"Sat." => "Thứ bảy",
"January" => "Tháng 1",
"February" => "Tháng 2",
"March" => "Tháng 3",
"April" => "Tháng 4",
"May" => "Tháng 5",
"June" => "Tháng 6",
"July" => "Tháng 7",
"August" => "Tháng 8",
"September" => "Tháng 9",
"October" => "Tháng 10",
"November" => "Tháng 11",
"December" => "Tháng 12",
"Jan." => "Tháng 1",
"Feb." => "Tháng 2",
"Mar." => "Tháng 3",
"Apr." => "Tháng 4",
"May." => "Tháng 5",
"Jun." => "Tháng 6",
"Jul." => "Tháng 7",
"Aug." => "Tháng 8",
"Sep." => "Tháng 9",
"Oct." => "Tháng 10",
"Nov." => "Tháng 11",
"Dec." => "Tháng 12",
"All day" => "Tất cả các ngày",
"New Calendar" => "Lịch mới",
"Missing or invalid fields" => "Thông tin thiếu hoặc không hợp lệ",
"Title" => "Tiêu đề",
"From Date" => "Từ ngày",
"From Time" => "Từ thời gian",
"To Date" => "Tới ngày",
"To Time" => "Tới thời gian",
"The event ends before it starts" => "Sự kiện này kết thúc trước khi nó bắt đầu",
"There was a database fail" => "Lỗi truy xuất cơ sở dữ liệu",
"Birthday" => "Ngày sinh nhật",
"Business" => "Công việc",
"Call" => "Số điện thoại",
"Clients" => "Máy trạm",
"Deliverer" => "Giao",
"Holidays" => "Ngày lễ",
"Ideas" => "Ý tưởng",
"Journey" => "Cuộc hành trình",
"Jubilee" => "Lễ kỷ niệm",
"Meeting" => "Hội nghị",
"Other" => "Khác",
"Personal" => "Cá nhân",
"Projects" => "Dự án",
"Questions" => "Câu hỏi",
"Work" => "Công việc",
"by" => "bởi",
"unnamed" => "Không tên",
"You do not have the permissions to update this calendar." => "Bạn không có quyền cập nhật lịch này",
"You do not have the permissions to delete this calendar." => "Bạn không có quyền xóa lịch này",
"You do not have the permissions to add to this calendar." => "Bạn không có quyền thêm lịch này",
"You do not have the permissions to add events to this calendar." => "Bạn không có quyền thêm các sự kiện vào lịch này.",
"You cannot add non-public events to a shared calendar." => "Bạn không thể thêm sự kiện không phải công cộng để chia sẻ lịch.",
"You do not have the permissions to delete this event." => "Bạn không có quyền xóa sự kiện này.",
"Busy" => "Bận",
"Show full event" => "Hiển thị đầy đủ sự kiện",
"Show only busy" => "Hiển thị bận",
"Hide event" => "Ẩn sự kiện",
"Does not repeat" => "Không lặp lại",
"Daily" => "Hàng ngày",
"Weekly" => "Hàng tuần",
"Every Weekday" => "Mỗi ngày trong tuần",
"Bi-Weekly" => "Hai tuần một lần",
"Monthly" => "Hàng tháng",
"Yearly" => "Hàng năm",
"never" => "không thay đổi",
"by occurrences" => "bởi sự kiện",
"by date" => "bởi ngày",
"by monthday" => "bởi ngày trong tháng",
"by weekday" => "bởi ngày trong tuần",
"events week of month" => "sự kiện trong tuần của tháng",
"first" => "đầu tiên",
"second" => "Thứ hai",
"third" => "Thứ ba",
"fourth" => "Thứ tư",
"fifth" => "Thứ năm",
"last" => "sau",
"by events date" => "Theo ngày tháng sự kiện",
"by yearday(s)" => "Theo ngày trong năm",
"by weeknumber(s)" => "Theo số tuần",
"by day and month" => "Theo ngày, tháng",
"Contact birthdays" => "Danh sách sinh nhật",
"Date" => "Ngày",
"Cal." => "Cal.",
"Day" => "Ngày",
"Week" => "Tuần",
"Month" => "Tháng",
"Today" => "Hôm nay",
"CalDav Link" => "Liên kết CalDav ",
"Timezone" => "Múi giờ",
"Update timezone automatically" => "Tự động cập nhập múi giờ",
"Time format" => "Định dạng thời gian",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Ngày bắt đầu trong tuần",
"Cache" => "Bộ đệm",
"Clear cache for repeating events" => "Xóa bộ nhớ đệm cho các sự kiện trùng nhau",
"Share Calendar" => "Chia sẻ lịch",
"Download" => "Tải về",
"Edit" => "Chỉnh sửa",
"Delete" => "Xóa",
"New calendar" => "Lịch mới",
"Edit calendar" => "sửa Lịch",
"Edit event" => "Sửa sự kiện",
"Save event" => "Lưu sự kiện",
"Delete event" => "Xóa sự kiện",
"Eventinfo" => "Thông tin sự kiện",
"Repeating" => "Lặp",
"Alarm" => "Nhắc nhở",
"Attendees" => "Người tham gia",
"Share" => "Chia sẻ",
"Title of the Event" => "Tên sự kiện",
"from" => "từ",
"to" => "đến",
"All Day Event" => "Sự kiện trong ngày",
"Advanced options" => "Tùy chọn nâng cao",
"Location" => "Nơi",
"Categories (separate by comma)" => "Thể loại (phân cách bằng dấu phẩy)",
"Edit categories" => "Sửa chuyên mục",
"Description" => "Mô tả",
"Export event" => "Trích xuất sự kiện",
"Repeat" => "Lặp lại",
"Advanced" => "Nâng cao",
"Select weekdays" => "Chọn ngày trong tuần",
"Select days" => "Chọn ngày",
"and the events day of year." => "và sự kiện của ngày trong năm",
"and the events day of month." => "và sự kiện của một ngày trong năm",
"Select months" => "Chọn tháng",
"Select weeks" => "Chọn tuần",
"and the events week of year." => "và sự kiện của tuần trong năm.",
"Interval" => "Khoảng từ",
"End" => "Kết thúc",
"occurrences" => "Sự kiện",
"Visibility to people shared with" => "Hiển thị với những người chia sẻ",
"create a new calendar" => "Tạo lịch mới",
"Import a calendar file" => "Nhập lịch từ tập tin",
"Please choose a calendar" => "Vui lòng chọn lịch",
"Name of new calendar" => "Tên lịch mới",
"Take an available name!" => "Chọn một tên tồn tại",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Đã tồn tại một lịch với tên này. Nếu bạn tiếp tục, những lịch này sẽ trộn với nhau.",
"Remove all events from the selected calendar" => "Xóa tất cả những sự kiện đã chọn trong calendar",
"Import" => "Nhập vào",
"Close Dialog" => "Đóng hộp thoại",
"Create a new event" => "Tạo một sự kiện mới",
"Create event" => "Tạo sự kiện",
"Share with user or group" => "Chia sẽ với người dùng hoặc nhóm",
"Unshare" => "Bỏ chia sẻ",
"Not shared with anyone" => "Không chia sẽ với bất cứ ai",
"Send Email" => "Gửi thư",
"Shared via calendar" => "Được chia sẻ qua lịch",
"Not shared with anyone via calendar" => "Không chia sẽ với bất cứ ai qua lịch",
"View an event" => "Xem một sự kiện",
"Category" => "Danh mục",
"No categories selected" => "Không danh sách nào được chọn",
"Access Class" => "Mức truy cập",
"From" => "Từ",
"at" => "tại",
"To" => "Tới"
);
